# avoid check note
if(getRversion() >= "2.15.1"){utils::globalVariables(c("obs","method","reu"))}

#' plot relative expanded uncertainty

#' plot_ru
#' @param reu_obj reu_obj object
#' @param DQO DQO Digital Quality Objective
#' @param ylim ylim
#' @param DESKTOP boolean
#' @param path path tempdir() by default
#' @param name name to be added to the filename
#' @param width_mm width in mm, 200 by default
#' @param height_mm height in mm, 200 by default
#' @keywords batqanger
#' @export
#' @examples
#' \dontrun{
#' plot_ru()
#' }
#
plot_ru <- function(reu_obj,DQO=30,ylim = c(0,100),DESKTOP=TRUE,path=tempdir(),name=NULL,width_mm=200,height_mm=200){


    if (inherits(reu_obj,"reu")){

      if (!DESKTOP) {

          filename <- normalizePath(file.path(path,paste0("plot_reu_",name,".tiff")),mustWork = FALSE)

          grDevices::tiff(filename = filename, width = width_mm, height = height_mm,
                units = "mm", pointsize = 12,
                compression = "lzw",
                bg = "transparent", res = 300)

      } else grDevices::dev.new()

      p <- ggplot2::ggplot(reu_obj, ggplot2::aes(x = obs, y = reu)) +
             ggplot2::geom_point(ggplot2::aes(colour = method),alpha=1/10) +
             ggplot2::geom_hline(yintercept = DQO)  +
             ggplot2::annotate("text", max(reu_obj$obs), DQO, vjust = -1, label = "DQO") +
             #ggplot2::geom_smooth(method="loess") + #takes ages on large datasets
             ggplot2::ylim(ylim[1],ylim[2]) +
             ggplot2::labs(
            x = "observation",
            y = "ratio [%]"
          )

      print(p)

      if (!DESKTOP) {
        grDevices::dev.off()
        return(filename)
      } else {
        return(TRUE)
      }

    }


}
