#' pred_rfci_wright2017_prime

#' pred_rfci_wright2017_prime
#' Adaptation of method from WRIGHT2017 with Ranger
#' @param model_rf Ranger RF model only
#' @param dataset dataset with target, Predictors
#' @param target column name of the target
#' @keywords cipred
#' @export
#' @examples
#' \dontrun{
#' pred_RFreg_wright2017_prime()
#' }
#
pred_rfci_wright2017_prime <- function(model_rf,dataset,target){
  tmp <- predict_ranger(model_rf,dataset)
  res <- data.frame(obs=dataset[[target]],
                    prediction=tmp$predictions,
                    se=tmp$se,
                    lower_pred_0_05 = tmp$predictions - 1.96*tmp$se,
                    upper_pred_0_05 = tmp$predictions + 1.96*tmp$se,
                    reu_0_05 = 100*1.96*tmp$se/tmp$predictions,
                    pvalue =stats::pnorm(q=dataset[[target]], mean=tmp$predictions,sd=tmp$se),
                    method      = rep("ranger_wright2017_prime",length(dataset[[target]])))
  return(res)
}

#' pred_rfci_wright2017

#' pred_rfci_wright2017
#' Adaptation of method from WRIGHT2017 with Ranger
#' @param model_rf Ranger RF model only
#' @param dataset dataset with Predictors
#' @keywords cipred
#' @export
#' @examples
#' \dontrun{
#' pred_rfci_wright2017()
#' }
#
pred_rfci_wright2017 <- function(model_rf,dataset){
  tmp <- predict_ranger(model_rf,dataset)
  res <- data.frame(prediction=tmp$predictions,
                    se=tmp$se,
                    lower_pred_0_05 = tmp$predictions - 1.96*tmp$se,
                    upper_pred_0_05 = tmp$predictions + 1.96*tmp$se,
                    reu_0_05 = 100*1.96*tmp$se/tmp$predictions,
                    method      = rep("ranger_wright2017",length(tmp$predictions)))
  return(res)
}
